@@ -2,8 +2,8 @@ context("testing number line object and functions")
 
 library(testthat)
 library(diyar)
-library(dplyr)
-library(lubridate)
+
+dmy <- function(x) as.Date(x, "%d/%m/%Y")
 
 t1 <- number_line(1, 10)
 t2 <- number_line(10, 1)
@@ -33,17 +33,17 @@ test_that("test direction of number line", {
 
   expect_equal(format(number_line()), "number_line(0)")
 
-   s1<- t1$start
-   s2<- t2$start
-   s3<- t3$start
-   s4<- t4$start
-   s5<- t5$start
+  s1<- t1$start
+  s2<- t2$start
+  s3<- t3$start
+  s4<- t4$start
+  s5<- t5$start
 
-   expect_equal(s1, 1)
-   expect_equal(s2, 10)
-   expect_equal(s3, 5)
-   expect_equal(s4, NA)
-   expect_equal(s5, 20)
+  expect_equal(s1, 1)
+  expect_equal(s2, 10)
+  expect_equal(s3, 5)
+  expect_equal(s4, NA)
+  expect_equal(s5, 20)
 
 })
 
@@ -94,17 +94,17 @@ test_that("test changing the number line", {
   expect_equal(nl_1, c(number_line(1, 10), number_line(5, 5)))
   expect_equal(nl_2, c(number_line(10, 19), number_line(5, 10)))
 
-  expect_equal(unique(c(rep(number_line(50, 200),3), number_line(5, 10))), c(number_line(50, 200, id =1, gid =1), number_line(5, 10, id =1, gid=1)))
+  expect_equal(unique(c(rep(number_line(50, 200),3), number_line(5, 10))), number_line(c(50,5), c(200,10), id =c(1,4), gid =c(1,4)))
   expect_equal(as.number_line(2), number_line(2,2,1,1))
-  expect_equal(expand_number_line(c(number_line(3,6), number_line(6,3)), 2), c(number_line(1,8,1,1), number_line(8,1,1,1)))
-  expect_equal(expand_number_line(c(number_line(3,6), number_line(6,3)), 2, "start"), c(number_line(1,6,1,1), number_line(8,3,1,1)))
-  expect_equal(expand_number_line(c(number_line(3,6), number_line(6,3)), 2, "end"), c(number_line(3,8,1,1), number_line(6,1,1,1)))
+  expect_equal(expand_number_line(c(number_line(3,6), number_line(6,3)), 2), c(number_line(1,8), number_line(8,1)))
+  expect_equal(expand_number_line(c(number_line(3,6), number_line(6,3)), 2, "start"), c(number_line(1,6), number_line(6,5)))
+  expect_equal(expand_number_line(c(number_line(3,6), number_line(6,3)), 2, "end"), c(number_line(3,8), number_line(8,3)))
   expect_equal(left_point(number_line(5, 1)), 5)
   expect_equal(right_point(number_line(5, 1)), 1)
   expect_equal(start_point(number_line(5, 1)), 1)
   expect_equal(end_point(number_line(5, 1)), 5)
-  expect_equal(sort(c(number_line(5,7), number_line(2,10))), c(number_line(2,10), number_line(5,7)))
-  expect_equal(sort(c(number_line(5,7), number_line(2,10)), decreasing = TRUE), rev(c(number_line(2,10), number_line(5,7))))
+  expect_equal(sort(c(number_line(5,7), number_line(2,10))), number_line(c(2,5),c(10,7), id =c(2,1), gid =c(2,1)))
+  expect_equal(sort(c(number_line(5,7), number_line(2,10)), decreasing = TRUE), rev(number_line(c(2,5),c(10,7), id =c(2,1), gid =c(2,1))))
   expect_equal(number_line_width(number_line(5,10)), 5)
   expect_equal(number_line_width(number_line(25,10)), -15)
   expect_equal(shift_number_line(number_line(5,6), 2), number_line(7,8))
@@ -118,15 +118,15 @@ test_that("test that error and warning messages are returned correctly", {
   #expect_error(shift_number_line(number_line(5,6), "A"), "'by' must be a numeric based object of length 1")
   expect_error(expand_number_line(1), "'x' is not a number_line object")
   #expect_error(expand_number_line(number_line(5,6), "A"), "'by' must be a numeric based object of length 1")
-  expect_error(expand_number_line(number_line(5,6), 1, 1), "'point' must be a character object of length 1")
-  expect_error(expand_number_line(number_line(5,6), 1, "AA"), "`point` must be either 'start','end' or 'both'")
+  expect_error(expand_number_line(number_line(5,6), 1, 1), "'point' must be a character object")
+  expect_error(expand_number_line(number_line(5,6), 1, "AA"), "`point` must be either 'left', 'right', 'start', 'end' or 'both'")
   expect_error(left_point(1), "'x' is not a number_line object")
   expect_error(right_point(1), "'x' is not a number_line object")
   expect_error(start_point(1), "'x' is not a number_line object")
   expect_error(end_point(1), "'x' is not a number_line object")
   expect_error(number_line_width(1), "'x' is not a number_line object")
   expect_error(reverse_number_line(number_line(10,100), c("both","increasing")), "'direction' must be a character of length 1")
-  expect_error(reverse_number_line(number_line(10,100), "increased"), "`direction` must be either 'increasing', 'decreasing', or 'both'")
+  expect_error(reverse_number_line(number_line(10,100), "increased"), "`direction` must be either 'increasing', 'decreasing' or 'both'")
   expect_warning(number_line(50, "20A"), "'l' and 'r' have different classes. It may need to be reconciled")
   expect_warning(number_line(50, "20A"), "NAs introduced by coercion")
 
@@ -138,16 +138,26 @@ test_that("test that error and warning messages are returned correctly", {
   expect_error(number_line(mtcars, mtcars), "'l' or 'r' aren't compatible for a number_line object")
   expect_error(number_line(1.2, 3.1, id = NA), "'id' must be numeric")
   expect_error(number_line(1.2, 3.1, gid = NA), "'gid' must be numeric")
-  expect_error(as.number_line(mtcars), "'x' can't be coerced to a number_line object")
+  expect_error(as.number_line(mtcars), "'x' can't be coerced to a `number_line` object")
 
 })
 
 test_that("test series function", {
-  expect_equal(number_line_sequence(number_line(1, 5)), c(1:5))
-  expect_equal(number_line_sequence(number_line(5, 1), .5), seq(5,1,-.5))
-  expect_equal(number_line_sequence(number_line(1, NA), .5), c(1, NA))
-  expect_equal(number_line_sequence(number_line(NA, 1), .5), c(NA_real_, NA_real_))
-  expect_equal(number_line_sequence(number_line(dmy("01/04/2019"), dmy("10/04/2019")), 1), seq(dmy("01/04/2019"), dmy("10/04/2019"), 1))
-  expect_error(number_line_sequence(1, .5), "'x' is not a number_line object")
-  expect_error(number_line_sequence(number_line(1,2), NA), "'by' must be a numeric object of length 1")
+  expect_equal(number_line_sequence(number_line(1, 5))[[1]], c(1:5))
+  expect_equal(number_line_sequence(number_line(5, 1), .5)[[1]], seq(5,1,-.5))
+  # expect_error(number_line_sequence(number_line(1, NA), .5)[[1]], "Finite values of 'x' required in indexes c(1)")
+  # expect_error(number_line_sequence(number_line(1, 2), NA)[[1]], "Finite values of 'by' required in indexes c(1)")
+  expect_equal(number_line_sequence(number_line(dmy("01/04/2019"), dmy("10/04/2019")), 1)[[1]], seq(dmy("01/04/2019"), dmy("10/04/2019"), 1))
+  expect_error(number_line_sequence(1, .5)[[1]], "'x' is not a number_line object")
 })
+
+a <- c(number_line(1,3), number_line(3,3), number_line(5,3))
+test_that("Convert `number_line to data.frame and vice versa`", {
+  expect_equal(a, to_s4(to_df(a)))
+  expect_error(to_s4(), "argument 'df' is missing, with no default")
+  expect_error(to_df(), "argument 's4' is missing, with no default")
+})
+
+
+
+
